"""In this example we plot a record fragment with sequence over multiple lines.
"""
from dna_features_viewer import BiopythonTranslator


class CustomTranslator(BiopythonTranslator):
    def compute_feature_color(self, feature):
        return {
            "restriction_site": "yellow",
            "CDS": "orange",
            "promoter": "darkblue",
            "terminator": "lightblue",
        }[feature.type]


translator = CustomTranslator()
graphic_record = translator.translate_record("example_sequence.gb")
subrecord = graphic_record.crop((1800, 2750))
subrecord.plot_on_multiple_pages(
    "multipage_plot.pdf",
    nucl_per_line=70,
    lines_per_page=7,
    plot_sequence=True,
)



from bokeh.embed import file_html
from bokeh.resources import CDN
from A_linear_plot import CustomTranslator

translator = CustomTranslator()
graphic_record = translator.translate_record("plasmid.gb")
bokeh_plot = graphic_record.plot_with_bokeh(figure_width=10, figure_height=2)
html = file_html(bokeh_plot, CDN, "my plot")
with open("F_bokeh_plot.html", "w") as f:
    f.write(html)



from dna_features_viewer import BiopythonTranslator, CircularGraphicRecord

class ExpressionUnitTranslator(BiopythonTranslator):

    def compute_feature_color(self, feature):
        color_map = {
            "rep_origin": "yellow",
            "CDS": "#ffd383",  # light orange
            "regulatory": "red",
            "misc_recomb": "darkblue",
            "misc_feature": "#d1e9f1",  # light blue
            "backbone": "darkblue",
        }
        return color_map[feature.type]

    def compute_feature_label(self, feature):
        if feature.type not in ["CDS", "regulatory"]:
            return None
        else:
            return BiopythonTranslator.compute_feature_label(self, feature)


translator = ExpressionUnitTranslator()
graphic_record = translator.translate_record(
    "plasmid.gb", record_class=CircularGraphicRecord
)
graphic_record.top_position = 4800  # sequence index appearing at the top
ax, _ = graphic_record.plot(figure_width=4)
ax.figure.savefig("C_circular_display.svg", bbox_inches="tight")


import ez_setup

ez_setup.use_setuptools()

from setuptools import setup, find_packages

exec(open("dna_features_viewer/version.py").read())  # loads __version__

setup(
    name="dna_features_viewer",
    version=__version__,
    author="Zulko",
    description="Plot features from DNA sequences (e.g. Genbank) with Python",
    long_description=open("pypi-readme.rst").read(),
    url="https://github.com/Edinburgh-Genome-Foundry/DnaFeaturesViewer",
    license="MIT",
    keywords="DNA Sequence Feature Genbank Biopython Matplotlib",
    packages=find_packages(exclude="docs"),
    install_requires=["matplotlib>=3", "Biopython"],
)



from A_linear_plot import CustomTranslator

translator = CustomTranslator()
graphic_record = translator.translate_record("plasmid.gb")
cropped_record = graphic_record.crop((6320, 6350))
cropped_record.ticks_resolution = 5  # One tick every 5 nucleotides
ax, _ = cropped_record.plot(figure_width=6)
cropped_record.plot_sequence(ax, guides_intensity=0.2)
cropped_record.plot_translation(
    ax=ax, location=(6335, 6350, -1), fontdict={"weight": "bold"}
)
ax.figure.savefig("B_detail_plot.svg", bbox_inches="tight")
